<?php

namespace DMG;

/**
 * Liveblog Embed
 */
class Liveblog_Embed {

	/**
	 * Query var
	 *
	 * @var string
	 */
	const QUERY_VAR = 'dmg_liveblog_embed_id';

	/**
	 * Register hooks
	 *
	 * @return void
	 */
	public static function init(){
		add_action( 'init', [ __CLASS__, 'register_endpoint' ] );
		add_action( 'template_redirect', [ __CLASS__, 'render_template' ] );
		add_filter( 'query_vars', [ __CLASS__, 'filter_query_vars' ] );
	}

	/**
	 * Filter query vars
	 *
	 * @param array $query_vars Existing query vars
	 * @return array Filtered query vars
	 */
	public static function filter_query_vars( $vars ) {
		$vars[] = self::QUERY_VAR;
		return $vars;
	}

	/**
	 * Register the embed endpoint URL
	 *
	 * @return void
	 */
	public static function register_endpoint(){
		add_rewrite_rule( 'liveblog/embed/([^/]+)/([^/]+)$', 'index.php?' . self::QUERY_VAR . '=$matches[1]&p=$matches[2]', 'top' );
	}

	/**
	 * Render the embed HTML template
	 *
	 * @return void
	 */
	public static function render_template(){
		if ( is_feed() || is_admin() ) {
			return;
		}
		$liveblog_id = get_query_var( self::QUERY_VAR );
		$parent_post = get_query_var( 'p' );
		if ( ! empty( $liveblog_id ) && ! empty( $parent_post ) ) {
			?>
<html>
	<head>
		<title>Liveblog</title>
		<meta name="robots" content="noindex">
		<meta name="viewport" content="width=device-width,minimum-scale=1,initial-scale=1">

		<?php
		/**
		 * Action for inserting markup into the embed head
		 *
		 * @param int $liveblog_id The liveblog ID
		 * @param int $parent_post The parent post ID
		 */
		do_action( 'dmg_liveblog_embed_head', $liveblog_id, $parent_post );
		?>

		<script>
			"use strict";

			/* 
			* The frontend needs to have the script to receive this post Message.
			* It will calculate the height of the content of the iframe window
			* and send it to the top window, which will resize the iframe.
			*/
			(function () {

				// counting the times we load this action to ensure it is sending an up to date height.
				var counter = 0;

				// applies the actiono on page load
				window.addEventListener('load', function () {
					setInterval();
				}, true);

				// set time out avoiding overlaps.
				function debounce(a, b, c) {
					var d;
					return function () {
						var e = this,
							f = arguments;
						clearTimeout(d), d = setTimeout(function () {
							d = null, c || a.apply(e, f);
						}, b), c && !d && a.apply(e, f);
					};
				}

				// The core oof this. Calculates the height and sends it to 'top' window.
				function sendPageHeight() {
					var docHeight = document.documentElement.offsetHeight;
					var message = {
						"iframe": window.name,
						"docHeight": docHeight
					};
					top.postMessage(JSON.stringify(message), '*');
				}

				function setInterval() {
					sendPageHeight();
					counter++;
					if (counter < 2) {
						setTimeout(setInterval, 1500);
					}
				}

				window.addEventListener('resize', debounce(sendPageHeight, 500));
			})();
		</script>
	</head>
	<body>

		<?php
		/**
		 * Action for inserting markup right after the opening <body> tag
		 *
		 * @param int $liveblog_id The liveblog ID
		 * @param int $parent_post The parent post ID
		 */
		do_action( 'dmg_liveblog_embed_body_open', $liveblog_id, $parent_post );
		?>

		<div id="dmg-liveblog-root"></div>
		<?php echo \DMG\Liveblog_Post_Type::get_inline_assets( $liveblog_id, $parent_post ); ?>

		<?php
		/**
		 * Action for inserting markup right before the closing </body> tag
		 *
		 * @param int $liveblog_id The liveblog ID
		 * @param int $parent_post The parent post ID
		 */
		do_action( 'dmg_liveblog_embed_body_close', $liveblog_id, $parent_post );
		?>
	</body>
</html>
<?php
		exit();
		}
	}
}