/**
 * WordPress dependencies
 */
import { subscribe, select, dispatch } from '@wordpress/data';

/**
 * Internal dependencies
 */
import insertNewEntryForm from '../utils';
import LoadMore, { loadEntries } from './components/load-more';
import '../store';

import './styles.scss';

// Bool for if we did initial loading
let didInitialLoad = false;

// Define ID for the components
const LOAD_MORE_ID = 'dmg-liveblog-entry-load-more';

/**
 * Stream in the latest entries
 */
const initiateEntriesStream = () => {

    // No need to fetch initial entries on new liveblog
    if (document?.location?.pathname === '/wp-admin/post-new.php') {
        return null;
    }

    // Set the key events
    const keyEvents = select('core/editor').getEditedPostAttribute('key_events');
    dispatch('dmg/liveblog').setKeyEvents(keyEvents);

    loadEntries(1);
}

/**
 * Subscribe to changes so we can insert the appender
 */
const unsubscribe = subscribe(() => {

    // Check if post is ready
    const postId = select('core/editor').getCurrentPostId();
    if (!postId) {
        return;
    }

    // Check if the root container is ready
    const rootContainer = document.querySelector('.is-root-container.block-editor-block-list__layout');
    if (!rootContainer) {
        return
    }

    unsubscribe();

    // Remove the permalink meta box
    dispatch( 'core/edit-post').removeEditorPanel( 'post-link' );

    // Add the Load More button
    const loadMoreContainer = document.createElement('div');
    loadMoreContainer.id = LOAD_MORE_ID;
    loadMoreContainer.classList.add('wp-block');
    ReactDOM.render(
        <LoadMore />,
        rootContainer.parentNode.insertBefore(loadMoreContainer, rootContainer.nextSibling)
    );

    // @TODO see if there's a way we can do this without setTimeout
    setTimeout(() => {
        insertNewEntryForm();
        initiateEntriesStream();
    }, 500)
});
