import edit from './edit'
import save from './save'
import { addFilter } from '@wordpress/hooks';
import { BlockControls } from '@wordpress/block-editor';
import { ToolbarButton } from '@wordpress/components';
import { registerBlockType } from '@wordpress/blocks';

// Internal dependencies
import block from './block.json';
import './styles.scss';

registerBlockType(
    block.name,
    {
        title: block.title,
        description: block.description,
        icon: block.icon,
        category: block.category,
        supports: {
            customClassName: false,
            className: false,
            html: false,
        },
        attributes: block.attributes,
        edit: edit,
        save: save,
    }
);

/**
 * Filter the tooltip to include an Edit Liveblog button
 */
const EditButton = BlockEdit => {
    return props => {

        if (props.name !== 'dmg/liveblog') {
            return <BlockEdit {...props} />;
        }

        let liveblogID = props.attributes.id || 0;
        return (
            <>
                <BlockControls>
                    <ToolbarButton
                        icon={'edit'}
                        label={'Edit liveblog (opens in new tab)'}
                        href={`/wp-admin/post.php?post=${liveblogID}&action=edit`}
                        target={'_blank'}
                        showTooltip
                    />
                </BlockControls>
                <BlockEdit {...props} />
            </>
        );
    };
};

addFilter('editor.BlockEdit', 'dmg', EditButton);
