# The React App

The app will expect two things to kick off. First, it will need a container root with an ID of `dmg-liveblog-root`:
```
<div id="dmg-liveblog-root"></div>
```

Next, it will need a JS object called `DMGLiveblog` containing the initial configuration. The following is an example showing the currently available configuration options:

```
var DMGLiveblog = {
    apiBase: 'https://inews-preprod.go-vip.net/wp-json/', // The WP-JSON endpoint to query
    liveblogID: 1759094, // The ID of the liveblog object
    embedParentURL: 'https://inewsint.co.uk/culture/liveblog-container-post-1759100', // The permalink URL of the WP Post that this liveblog is rendered on
    showHeadline: true, // Whether or not to show/hide the Liveblog post.title
    showOrderSelector: true, // Whether or not to render the dropdown to select to order by date ASC/DESC
    emitSchema: true, // Whether or not to render the Schema.org LiveBlogPosting json+ld
    keyEvents: {
        active: true, // Whether or not to render the Key Events
        container: { // Optional object for rendering Key Events in an arbitrary place on the page. Should have only one of the following properties:
            selector: '#dmg-liveblog-key-events', // Specify a selector to render key events within
            insertBefore: null,// Specify a selector that key events should render before
            insertAfter: null, // Specify a selector that key events should render after
            appendTo: null, // Specify a selector that key events should be appended to
        },
        count: 100, // How many Key Events to show
    },
    entries: {
        count: 10, // This is the per_page number to show
    },
    shareTools: {
        active: true, // Render share tools per Entry
        platforms: [ // List of share tools to supports
            'facebook',
            'twitter',
            'email'
        ],
    },
}
```

## index.js

This is where we render the app. We look for the `dmg-liveblog-root` to render the ReactDOM root and, optionally, check the configuration to see if we need to render the Key Events somewhere else on the page.

## App.js

This is the main app component. On initial load, we perform a few one-time tasks:
1. Fetch the liveblog object, including key events.
2. Fetch the first page of entries.
3. Register our polling functionality to pull new entries every 10 seconds.

Additionally, if we have landed on a hash route (i.e. via a shared individual entry link), we will load the appropriate entry by fetching additional pages, if necessary, and jumping to the entry on the page.

## /assets/

Currently just the home for our SVG icon sprite. All icons are from Icomoon.

## /components/

Most UI elements have their own functional component so that they can read data from the Redux store using `useSelector` or dispatch actions with `useDispatch`. 

The `Icon` component references SVGs defined in our sprite and is used by all our social buttons. We're required to output that sprite as a component in App.js.

## /store/

The application state is divided into three "slices":
1. The initial configuration state.
2. Entries – this is where all fetching and polling of new entries take place.
3. Liveblog – the parent liveblog object.

## /utils/

This directory just contains small utility files for triggering custom events and retrieving API data from WP-JSON.
