import { useSelector } from 'react-redux';

/**
 * Internal dependencies
 */
import { getConfiguration } from '../store/slices/Configuration'

import Facebook from './social/Facebook'
import Twitter from './social/Twitter'
import WhatsApp from './social/WhatsApp'
import Email from './social/Email'
import Link from './social/Link'

/**
 * Liveblog entry
 *
 * @param {object}   props      The entry properties.
 * @param {object}   props.post The entry WordPress post object.
 * @return {function} Render the entry
 */
const Entry = ({post}) => {
  
  // Get configuration object
  const configuration = useSelector(getConfiguration);

  // Map configured platforms to their corresponding components
  const platforms = configuration?.shareTools?.platforms.map( (platform) => {
    let component = null
    switch(platform) {

      case 'facebook':
        component = <Facebook post={post} />
        break

      case 'twitter':
        component = <Twitter post={post} />
        break

      case 'whatsapp':
        component = <WhatsApp post={post} />
        break

      case 'email':
        component = <Email post={post} />
        break

      case 'link':
        component = <Link post={post} />
        break

      default:
        component = null
    }
    return component
  }) ?? []

  return (
    <div
      className="dmg-liveblog__entry-container"
      data-entry={post.id}>
      <div
        className="dmg-liveblog__entry-body"
        dangerouslySetInnerHTML={{
          __html: post.content.rendered
        }}
      />
      {configuration?.shareTools?.active &&
        <div className="dmg-liveblog__share-tools">
          {platforms}
        </div>
      }
    </div>
  )
}

export default Entry;
