import { useSelector, useDispatch } from 'react-redux';

/**
 * Internal dependencies
 */
import { getConfiguration } from '../store/slices/Configuration'
import { getLiveblog } from '../store/slices/Liveblog';
import { fetchAndSeek } from '../store/slices/Entries';
import { triggerEvent } from '../utils/events'

/**
 * Key event
 *
 * @param {object}   props      The key event properties.
 * @param {object}   props.post The key event WordPress post object.
 * @return {function} Render the key event
 */
const KeyEvent = ({post}) => {

  const dispatch = useDispatch()

  /**
   * Scroll key event into view (loading it if necessary)
   */
  const scrollIntoView = (e, entryId) => {
    triggerEvent('dmgLiveblog:keyEvent:click', {
      href: e.target.href,
      label: post.title.rendered
    })
    const entry = document.querySelector(`[data-entry="${entryId}"]`)
    if (entry) {
      entry.scrollIntoView()
    } else {
      document.querySelector('.dmg-liveblog__load-more').scrollIntoView(false)
      dispatch(fetchAndSeek(entryId))
    }
  }

  return (
    <li
      className="dmg-liveblog__key-event">
      <a
        dangerouslySetInnerHTML={{
          __html: post.title.rendered
        }}
        href={'#entry-' + post.id}
        onClick={(e) => scrollIntoView(e, post.id)}
        data-entry-date={post.date_gmt + 'Z'}
      />
    </li>
  )
}

/**
 * Component for all key events
 */
const KeyEvents = () => {

  // Get configuration
  const configuration = useSelector(getConfiguration)
  const liveblog = useSelector(getLiveblog);

  return (
    <>
      {configuration?.keyEvents?.active &&
        liveblog?.key_events.length > 0 &&
        <div className="dmg-liveblog__key-events">
          {liveblog?.key_events?.map((keyEvent) => <KeyEvent post={keyEvent} key={keyEvent.id} />)}
        </div>
      }
    </>
  )
}

export default KeyEvents;
