import { useSelector, useDispatch } from 'react-redux';

/**
 * Internal dependencies
 */
import { incrementPage, fetchEntries, isLoading } from '../store/slices/Entries';
import { triggerEvent } from '../utils/events'
import store from '../store';

/**
 * Load More button
 *
 * @return {function} Render the Load More button
 */
const LoadMore = () => {
  const dispatch = useDispatch();
  const loading = useSelector(isLoading)

  /**
   * Increment the page value and fetch
   */
  const loadNextPage = () => {
    dispatch(incrementPage())
    dispatch(fetchEntries())
    triggerEvent('dmgLiveblog:loadMore', {page: store.getState().entries.page})
  }
  
  return (
    <>
      {loading &&
        <div className="dmg-liveblog__loader">
          <span />
        </div>
      }
      {!loading &&
        <button
          className="dmg-liveblog__load-more"
          onClick={() => loadNextPage()}>
          Load More
        </button>
      }
    </>
  )
}

export default LoadMore;
