import { useDispatch } from 'react-redux';

/**
 * Internal dependencies
 */
import { setOrder, resetPage, fetchEntries } from '../store/slices/Entries';
import { triggerEvent } from '../utils/events'

/**
 * The order selector
 *
 * @return {function} Render the order selector
 */
const OrderSelector = () => {
  const dispatch = useDispatch();

  /**
   * Change the order
   */
  const updateOrder = (e) => {
    dispatch(setOrder({order: e.target.value}))
    dispatch(resetPage())
    dispatch(fetchEntries())
    triggerEvent('dmgLiveblog:updateOrder', e.target.value)
  }

  return (
    <div
      className="dmg-liveblog__order-selector">
      <label
        for="dmg-liveblog-order-selector">
        Sort:
      </label>
      <select
        name="dmg-liveblog-order-selector"
        onChange={(val) => updateOrder(val)}>
        <option value="desc">Newest first</option>
        <option value="asc">Oldest first</option>
      </select>
    </div>
  )
}

export default OrderSelector;
