import { useState } from 'react';

/**
 * Internal dependencies
 */
import Icon from '../Icon'
import { triggerEvent } from '../../utils/events'

/**
 * Link Icon
 *
 * @param {object}   props      The entry properties.
 * @param {object}   props.post The entry WordPress post object.
 * @return {function} Render the entry
 */
const Link = ({post}) => {

  const [copied, setCopied] = useState(false);

  /**
   * Copy callback
   *
  * @param {object} post The entry WordPress post object
   */
  const copy = (post) => {
    navigator.clipboard.writeText(post.link);
    triggerEvent('dmgLiveblog:shareButtons:copyLink', {post})
    setCopied(true)
    setTimeout(() => {
      setCopied(false)
    }, 1000);
  }

  // Define classes used
  let classes = ['dmg-liveblog__social-icon', 'dmg-liveblog__social-icon-link']
  if (copied) {
    classes.push('dmg-liveblog__social-icon-link--copied')
  }

  return (
    <div
      className={classes.join(' ')}
      onClick={() => copy(post)}>
      <Icon name="link" />
    </div>
  )
}

export default Link
