import { createAsyncThunk, createSlice } from '@reduxjs/toolkit'

/**
 * Internal dependencies
 */
import { WP } from '../../utils/wpapi';

/**
 * Create a thunk for fetching the liveblog
 */
export const fetchLiveblog = createAsyncThunk(
  'liveblog/fetch',
  async (_: void, thunkAPI) => {
    const liveblogID = thunkAPI.getState().configuration.liveblogID
    const response = await WP
      .liveblog()
      .id(liveblogID)
      .then((data) => data)
      .catch((err) => err);

    return response.error ? [] : response;
  }
)

/**
 * Create a slice
 */
export const liveblog = createSlice({
  name: 'liveblog',
  initialState: {
    post: null
  },
  reducers: {},
  extraReducers: (builder) => {
    
    // When liveblog is successfully fetched, set the post property
    builder.addCase(fetchLiveblog.fulfilled, (state, action) => {
      state.post = action.payload
    })
  }
})

export const { addLiveblog } = liveblog.actions


// The function below is called a selector and allows us to select a value from
// the state. Selectors can also be defined inline where they're used instead of
// in the slice file. For example: `useSelector((state) => state.counter.value)`
export const getLiveblog = (state) => state.liveblog.post

export default liveblog.reducer